// Будем минимизировать не количество групп, а количество разбиений. Например, если делегация
// распределена по 3 автобусам, это даёт нам 2 разбиения. Очевидно, что обе постановки эквивалентны.

#include <cassert>
#include <cstdio>
#include <iostream>
#include <utility>
#include <vector>

using namespace std;

const int maxn = 100;
const int inf = 1000 * 1000 * 1000;

int n, a[maxn];
int m, b[maxn];

// Инвариант: d[i][j][k] означает минимальное количество разбиений, которого можно достичь, рассадив
// делегации с номерами 0..i-1 и еще j человек из делегации с номером i в первые k автобусов. Для
// делегации i одно разбиение уже посчитано (если только j != 0). При этом оптимальный ответ получен
// из состояния (prev_i[i][j][k], prev_j[i][j][k], k-1).
int d[maxn + 1][maxn + 1][maxn + 1];
int prev_i[maxn + 1][maxn + 1][maxn + 1];
int prev_j[maxn + 1][maxn + 1][maxn + 1];

vector<pair<int, int> > ans[maxn];

void try_improve(int i, int j, int k, int i1, int j1, int k1, int add) {
    assert(0 <= i && i <= maxn);
    assert(0 <= j && j <= maxn);
    assert(0 <= k && k <= maxn);
    assert(0 <= i1 && i1 <= maxn);
    assert(0 <= j1 && j1 <= maxn);
    assert(0 <= k1 && k1 <= maxn);
    if (d[i][j][k] + add < d[i1][j1][k1]) {
        d[i1][j1][k1] = d[i][j][k] + add;
        prev_i[i1][j1][k1] = i;
        prev_j[i1][j1][k1] = j;
        assert(k + 1 == k1);
    }
}

void restore(int i, int j, int k) {
    assert(d[i][j][k] != inf);
    if (!i && !j) {
        assert(!d[i][j][k]);
        return;
    }
    const int pi = prev_i[i][j][k];
    const int pj = prev_j[i][j][k];
    restore(pi, pj, k - 1);

    // Вспоминаем все делегации, которые оказались в автобусе k - 1 (автобусы в этом решении
    // считаются от 0, при этом k означает количество заполненных автобусов в текущем состоянии,
    // т.е. они имеют номера с 0 по k - 1).
    for (int deleg = pi; deleg <= i; deleg++) {
        int q = a[deleg];
        if (deleg == pi) {
            q -= pj; // Этих не считаем -- они сидят в автобусе k - 2.
        }
        if (deleg == i) {
            q -= a[i] - j; // Этих не считаем -- они сидят в автобусе k.
        }
        if (q) {
            ans[deleg].push_back(make_pair(k - 1, q));
        }
    }
}

int main() {
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);

    cin >> n;
    assert(1 <= n && n <= maxn);
    int sum_a = 0;
    for (int i = 0; i < n; i++) {
        cin >> a[i];
        sum_a += a[i];
        assert(1 <= a[i] && a[i] <= maxn);
    }
    cin >> m;
    assert(1 <= m && m <= maxn);
    int sum_b = 0;
    for (int i = 0; i < m; i++) {
        cin >> b[i];
        sum_b += b[i];
        assert(1 <= b[i] && b[i] <= maxn);
    }
    assert(sum_a <= sum_b);

    for (int i = 0; i <= maxn; i++) {
        for (int j = 0; j <= maxn; j++) {
            for (int k = 0; k <= maxn; k++) {
                d[i][j][k] = inf;
            }
        }
    }
    d[0][0][0] = 0;

    for (int k = 0; k < m; k++) {
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < a[i]; j++) {
                if (d[i][j][k] == inf) continue;
                // Определяем, кто войдёт в автобус k если его заполнить целиком.
                int i1 = i;
                int sum = 0;
                int rest = a[i] - j;
                while (i1 < n && sum + rest <= b[k]) {
                    sum += rest;
                    i1++;
                    rest = a[i1];
                }

                // В этом месте соблюдается инвариант: в автобус k могут войти
                // - оставшиеся члены делегации i (если только i < i1);
                // - делегации с номерами с i + 1 по i1 - 1 целиком;
                // - некоторые члены делегации i1 (возможно, нулевое их число).
                // При этом переменная sum равна суммарному количеству людей, оставшихся в делегации
                // i и состоящих в делегациях с i + 1 по i1 - 1.

                // Заполняем автобус всеми вплоть до делегации i1, из которой никого не берём.
                // Промежуточных вариантов рассматривать не нужно по жадным соображениям: если бы
                // удалось построить решение, в котором некая делегация входит в автобус k целиком,
                // но мы её перенесли на следующий автобус, то можно её вернуть в автобус k и
                // решение не ухудшится.
                if (i1 > i) {
                    try_improve(i, j, k, i1, 0, k + 1, 0);
                }
                // Заполняем автобус всеми, кто туда может войти, в том числе и из делегации i1.
                if (i1 < n && sum < b[k]) {
                    try_improve(i, j, k, i1, (i1 == i ? j : 0) + b[k] - sum, k + 1, 1);
                }
                // Частный случай. Пропускаем весь автобус.
                try_improve(i, j, k, i, j, k + 1, 0);
            }
        }
    }

    int best_ans = inf;
    int best_k = -1;
    for (int k = 0; k <= m; k++) {
        if (d[n][0][k] < best_ans) {
            best_ans = d[n][0][k];
            best_k = k;
        }
    }
    assert(best_ans != inf);
    restore(n, 0, best_k);
    for (int i = 0; i < n; i++) {
        cout << ans[i].size() << endl;
        for (int j = 0; j < ans[i].size(); j++) {
            cout << ans[i][j].first + 1 << " " << ans[i][j].second << endl;
        }
    }
}
